{ config, pkgs, ... }:

{
  programs.home-manager.enable = true;

  home.username = "jordan";
  home.homeDirectory = "/home/jordan";

  home.stateVersion = "22.11";

  home.packages = with pkgs; [
    bind
    bmon
    fd
    ffmpeg
    iotop
    noto-fonts
    ripgrep
    rsync
    tcpdump
    tokei
    tree
    ubuntu_font_family
    wl-clipboard
    zsh-autosuggestions
    zsh-fast-syntax-highlighting
    zsh-history-substring-search
  ];

  programs.gpg.enable = true;

  programs.firefox = {
    enable = true;
  };

  programs.fzf = {
    enable = true;
    enableZshIntegration = true;
    defaultCommand = "fd --type f --hidden --follow --exclude .git";
  };

  programs.git = {
    enable = true;
    aliases = {
      amend = "commit --amend";
      lg = "log --color --graph --abbrev-commit --";
      ls = "ls-files";
      unadd = "reset HEAD";
      undo-commit = "reset --soft \"HEAD^\"";
    };
    userEmail = "jordan@vimium.com";
    userName = "Jordan Holt";
    signing = {
      key = "B8CFFF61F1CCF520";
      signByDefault = true;
    };
    extraConfig = {
      rebase.autosquash = true;
      push.default = "current";
      pull.rebase = true;
    };
  };

  programs.neovim = {
    enable = true;
    vimAlias = true;
    vimdiffAlias = true;
  };

  programs.nnn = {
    enable = true;
  };

  programs.password-store = {
    enable = true;
    package = pkgs.pass.withExtensions (exts: [ exts.pass-otp ]);
  };

  programs.yt-dlp = {
    enable = true;
    extraConfig = ''
      --ignore-errors
      -o ~/Videos/%(title)s.%(ext)s
    '';
  };

  programs.zsh = {
    enable = true;
    enableCompletion = true;
    shellAliases = {
      cp = "cp -iv";
      mv = "mv -iv";
      rm = "rm -v";
      mkdir = "mkdir -v";
      ls = "ls -h --color=auto --group-directories-first";
      e = "nvim";
      f = "nnn";
      g = "git";
      n = "nnn";
      v = "nvim";
    };
  };

  xdg.enable = true;
}
